embassy-sync

Crates

git

Versions

default

Flavors

PanicMutex

Type Alias PanicMutex 

pub type PanicMutex<T> = Mutex<PanicRawMutex, T>;
A mutex that panics if locked from multiple contexts.

Safety

This mutex is safe to share between different executors and interrupts.

Aliased Type

pub struct PanicMutex<T> { /* private fields */ }